==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/General/udisks/translations/udisks_plugin_sr_RS.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_RS">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>UDisks Plugin Settings</source>
        <translation>Поставке за Удискс</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Откривање музичког диска</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Аутоматски додај нумере на листу</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Аутоматски уклони нумере са листе</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Откривање уклоњивих уређаја</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Аутоматски додај фајлове на листу</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Аутоматски уклони фајлове са листе</translation>
    </message>
</context>
<context>
    <name>UDisksFactory</name>
    <message>
        <location filename="../udisksfactory.cpp" line="30"/>
        <source>UDisks Plugin</source>
        <translation>Удискс</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="50"/>
        <source>About UDisks Plugin</source>
        <translation>О прикључку за UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="51"/>
        <source>Qmmp UDisks Plugin</source>
        <translation>Кумп прикључак за UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="52"/>
        <source>This plugin provides removable devices detection using UDisks</source>
        <translation>Омогућује откривање уклоњивих уређаја користећи UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>UDisksPlugin</name>
    <message>
        <location filename="../udisksplugin.cpp" line="154"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Додај диск „%1“</translation>
    </message>
    <message>
        <location filename="../udisksplugin.cpp" line="160"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Додај складишни простор „%1“</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/General/udisks/translations/udisks_plugin_sr_RS.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_RS">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>UDisks Plugin Settings</source>
        <translation>Поставке за Удискс</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Откривање музичког диска</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Аутоматски додај нумере на листу</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Аутоматски уклони нумере са листе</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Откривање уклоњивих уређаја</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Аутоматски додај фајлове на листу</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Аутоматски уклони фајлове са листе</translation>
    </message>
</context>
<context>
    <name>UDisksFactory</name>
    <message>
        <location filename="../udisksfactory.cpp" line="31"/>
        <source>UDisks Plugin</source>
        <translation>Удискс</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="51"/>
        <source>About UDisks Plugin</source>
        <translation>О прикључку за UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="52"/>
        <source>Qmmp UDisks Plugin</source>
        <translation>Кумп прикључак за UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="53"/>
        <source>This plugin provides removable devices detection using UDisks</source>
        <translation>Омогућује откривање уклоњивих уређаја користећи UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>UDisksPlugin</name>
    <message>
        <location filename="../udisksplugin.cpp" line="154"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Додај диск „%1“</translation>
    </message>
    <message>
        <location filename="../udisksplugin.cpp" line="160"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Додај складишни простор „%1“</translation>
    </message>
</context>
</TS>
